@@ -1813,6 +1813,12 @@ libwacom_stylus_is_eraser(const WacomStylus *stylus)
 	return libwacom_stylus_get_eraser_type(stylus) != WACOM_ERASER_NONE;
 }
 
+LIBWACOM_EXPORT int
+libwacom_stylus_is_generic(const WacomStylus *stylus)
+{
+	return stylus->is_generic_stylus;
+}
+
 LIBWACOM_EXPORT int
 libwacom_stylus_has_lens(const WacomStylus *stylus)
 {
